@@ -3,8 +3,8 @@ package Colouring::In;
 use 5.006;
 use strict;
 use warnings;
-
-our $VERSION = '0.14';
+use smallnum;
+our $VERSION = '0.15';
 
 our %TOOL;
 
@@ -111,7 +111,8 @@ BEGIN {
 				$h = $s = 0;
 			}
 			else {
-				$s = $l > 0.5 ? $d / ( 2 - $max - $min ) : $d / ( $max + $min );
+				$d = smallnum::smallnum($d); #grrr
+				$s = $l > 0.5 ? ($d / ( 2 - $max - $min )) : ($d / ( $max + $min ));
 				$h = ( $max == $r )
 					? ( $g - $b ) / $d + ( $g < $b ? 6 : 0 )
 					: ( $max == $g )
@@ -209,7 +210,6 @@ sub toHEX {
 
 sub toHSL {
 	my $hsl = $TOOL{asHSL}($_[0]);
-
 	sprintf( "hsl(%s,%s,%s)",
 		$hsl->{h},
 		$TOOL{percent}( $hsl->{s} ),
@@ -291,13 +291,11 @@ sub fadeout {
 
 sub fadein {
 	my ($colour, $amt, $meth, $hsl) = @_;
-
 	($hsl, $colour) = $TOOL{hsl}($colour);
-
 	$hsl->{a} += ($meth && $meth eq 'relative')
 		? $hsl->{a} * $TOOL{depercent}($amt)
  		: $TOOL{depercent}($amt);
-
+	$hsl->{a} = smallnum::smallnum($hsl->{a});
 	return $colour->hsla( $TOOL{hash2array}( $hsl, 'h', 's', 'l', 'a' ) );
 }
 
@@ -319,7 +317,7 @@ Colouring::In - color or colour.
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =cut
 
